@@ -1,2 +1,2 @@
 from .encode import encode, encode_with_relatives
-from .decode import decode
+from .decode import decode, decode_from_dict
